Release Notes — Fedimg 1.3.0 documentation

# Release Notes

## 2.0.0

### Deprecation

- The fedmsg message `fedimg.image.upload` has been deprecated for all other regions other than the `base_region` (#97).

### Bug fixes

- Refactor the `FedimgConsumer` to handle F28 Two week Atomic (#123).

### Developer Improvements

- Fix the tests for `utils.py` (#124).
- Fix the FSF address in setup.py messed up during the version bump (#127).
- Migrate from nose to pytest (#128).
- Fix the filename type for CHANGELOG.rst (#129).
- Raise exceptions when shell execution fails (#130).
- Refactor the docs to use sphinx, and update the latest architecture (#131).

### Contributors

The following developers contributed patches to Fedimg 2.0.0:

- Sayan Chowdhury